@@ -249,7 +249,7 @@ class Repo(IInclude):
     for file_glob in self.glob.split("|"):
       lines += ["{% tabs %}"]
       for file in self.path.glob(file_glob):
-        if file.is_file() and file not in ignored:
+        if file.is_file() and file not in ignored and file.parent not in ignored:
           lines += [f"{{% tab title=\'{file.relative_to(self.path)}\' %}}\n"]
           suffix = file.suffix[1:]
           lines += [f"````{suffix if suffix else 'txt'}"]
